@@ -6,6 +6,14 @@ except ImportError:
     # python 3.8 and later
     from importlib.metadata import version  # type: ignore
 
+# Library imports need to be on top to avoid problems with
+# circular dependencies. As these do not change that often
+# they can be marked to be skipped for isort runs.
+from miio.device import Device, DeviceStatus  # isort: skip
+from miio.exceptions import DeviceError, DeviceException  # isort: skip
+from miio.miot_device import MiotDevice  # isort: skip
+
+# Integration imports
 from miio.airconditioner_miot import AirConditionerMiot
 from miio.airconditioningcompanion import (
     AirConditioningCompanion,
@@ -25,23 +33,32 @@ from miio.airpurifier_miot import AirPurifierMB4, AirPurifierMiot
 from miio.airqualitymonitor import AirQualityMonitor
 from miio.airqualitymonitor_miot import AirQualityMonitorCGDN1
 from miio.aqaracamera import AqaraCamera
-from miio.ceil import Ceil
 from miio.chuangmi_camera import ChuangmiCamera
 from miio.chuangmi_ir import ChuangmiIr
 from miio.chuangmi_plug import ChuangmiPlug, Plug, PlugV1, PlugV3
 from miio.cooker import Cooker
 from miio.curtain_youpin import CurtainMiot
-from miio.device import Device, DeviceStatus
-from miio.exceptions import DeviceError, DeviceException
-from miio.fan import Fan, FanP5, FanSA1, FanV2, FanZA1, FanZA4
-from miio.fan_leshow import FanLeshow
-from miio.fan_miot import Fan1C, FanMiot, FanP9, FanP10, FanP11, FanZA5
 from miio.gateway import Gateway
 from miio.heater import Heater
 from miio.heater_miot import HeaterMiot
 from miio.huizuo import Huizuo, HuizuoLampFan, HuizuoLampHeater, HuizuoLampScene
+from miio.integrations.fan.dmaker import Fan1C, FanMiot, FanP5, FanP9, FanP10, FanP11
+from miio.integrations.fan.leshow import FanLeshow
+from miio.integrations.fan.zhimi import Fan, FanZA5
+from miio.integrations.humidifier.deerma import AirHumidifierJsqs
+from miio.integrations.light.philips import (
+    Ceil,
+    PhilipsBulb,
+    PhilipsEyecare,
+    PhilipsMoonlight,
+    PhilipsRwread,
+    PhilipsWhiteBulb,
+)
 from miio.integrations.petwaterdispenser import PetWaterDispenser
-from miio.integrations.vacuum.dreame.dreamevacuum_miot import DreameVacuumMiot
+from miio.integrations.vacuum.dreame.dreamevacuum_miot import (
+    DreameVacuum,
+    DreameVacuumMiot,
+)
 from miio.integrations.vacuum.mijia import G1Vacuum
 from miio.integrations.vacuum.roborock import RoborockVacuum, Vacuum, VacuumException
 from miio.integrations.vacuum.roborock.vacuumcontainers import (
@@ -55,11 +72,6 @@ from miio.integrations.vacuum.roborock.vacuumcontainers import (
 from miio.integrations.vacuum.roidmi.roidmivacuum_miot import RoidmiVacuumMiot
 from miio.integrations.vacuum.viomi.viomivacuum import ViomiVacuum
 from miio.integrations.yeelight import Yeelight
-from miio.miot_device import MiotDevice
-from miio.philips_bulb import PhilipsBulb, PhilipsWhiteBulb
-from miio.philips_eyecare import PhilipsEyecare
-from miio.philips_moonlight import PhilipsMoonlight
-from miio.philips_rwread import PhilipsRwread
 from miio.powerstrip import PowerStrip
 from miio.protocol import Message, Utils
 from miio.pwzn_relay import PwznRelay
