@@ -21,6 +21,7 @@ from . import (
     AirFreshT2017,
     AirHumidifier,
     AirHumidifierJsq,
+    AirHumidifierJsqs,
     AirHumidifierMjjsq,
     AirPurifier,
     AirPurifierMiot,
@@ -32,9 +33,8 @@ from . import (
     ChuangmiPlug,
     Cooker,
     Device,
-    Fan,
+    DreameVacuum,
     FanLeshow,
-    FanMiot,
     Gateway,
     Heater,
     PhilipsBulb,
@@ -79,23 +79,9 @@ from .chuangmi_plug import (
     MODEL_CHUANGMI_PLUG_V2,
     MODEL_CHUANGMI_PLUG_V3,
 )
-from .fan import (
-    MODEL_FAN_P5,
-    MODEL_FAN_SA1,
-    MODEL_FAN_V2,
-    MODEL_FAN_V3,
-    MODEL_FAN_ZA1,
-    MODEL_FAN_ZA3,
-    MODEL_FAN_ZA4,
-)
-from .fan_miot import (
-    MODEL_FAN_1C,
-    MODEL_FAN_P9,
-    MODEL_FAN_P10,
-    MODEL_FAN_P11,
-    MODEL_FAN_ZA5,
-)
 from .heater import MODEL_HEATER_MA1, MODEL_HEATER_ZA1
+from .integrations.fan.dmaker import FanMiot
+from .integrations.fan.zhimi import Fan, FanZA5
 from .powerstrip import MODEL_POWER_STRIP_V1, MODEL_POWER_STRIP_V2
 from .toiletlid import MODEL_TOILETLID_V1
 
@@ -153,6 +139,7 @@ DEVICE_MAP: Dict[str, Union[Type[Device], partial]] = {
         AirHumidifierMjjsq, model=MODEL_HUMIDIFIER_MJJSQ
     ),
     "deerma-humidifier-jsq1": partial(AirHumidifierMjjsq, model=MODEL_HUMIDIFIER_JSQ1),
+    "deerma-humidifier-jsqs": AirHumidifierJsqs,
     "yunmi-waterpuri-v2": WaterPurifier,
     "yunmi.waterpuri.lx9": WaterPurifierYunmi,
     "yunmi.waterpuri.lx11": WaterPurifierYunmi,
@@ -184,18 +171,18 @@ DEVICE_MAP: Dict[str, Union[Type[Device], partial]] = {
     "lumi-camera-aq2": AqaraCamera,
     "yeelink-light-": Yeelight,
     "leshow-fan-ss4": FanLeshow,
-    "zhimi-fan-v2": partial(Fan, model=MODEL_FAN_V2),
-    "zhimi-fan-v3": partial(Fan, model=MODEL_FAN_V3),
-    "zhimi-fan-sa1": partial(Fan, model=MODEL_FAN_SA1),
-    "zhimi-fan-za1": partial(Fan, model=MODEL_FAN_ZA1),
-    "zhimi-fan-za3": partial(Fan, model=MODEL_FAN_ZA3),
-    "zhimi-fan-za4": partial(Fan, model=MODEL_FAN_ZA4),
-    "dmaker-fan-1c": partial(FanMiot, model=MODEL_FAN_1C),
-    "dmaker-fan-p5": partial(Fan, model=MODEL_FAN_P5),
-    "dmaker-fan-p9": partial(FanMiot, model=MODEL_FAN_P9),
-    "dmaker-fan-p10": partial(FanMiot, model=MODEL_FAN_P10),
-    "dmaker-fan-p11": partial(FanMiot, model=MODEL_FAN_P11),
-    "zhimi-fan-za5": partial(FanMiot, model=MODEL_FAN_ZA5),
+    "zhimi-fan-v2": Fan,
+    "zhimi-fan-v3": Fan,
+    "zhimi-fan-sa1": Fan,
+    "zhimi-fan-za1": Fan,
+    "zhimi-fan-za3": Fan,
+    "zhimi-fan-za4": Fan,
+    "dmaker-fan-1c": FanMiot,
+    "dmaker-fan-p5": Fan,
+    "dmaker-fan-p9": FanMiot,
+    "dmaker-fan-p10": FanMiot,
+    "dmaker-fan-p11": FanMiot,
+    "zhimi-fan-za5": FanZA5,
     "tinymu-toiletlid-v1": partial(Toiletlid, model=MODEL_TOILETLID_V1),
     "zhimi-airfresh-va2": partial(AirFresh, model=MODEL_AIRFRESH_VA2),
     "zhimi-airfresh-va4": partial(AirFresh, model=MODEL_AIRFRESH_VA4),
@@ -208,6 +195,10 @@ DEVICE_MAP: Dict[str, Union[Type[Device], partial]] = {
     "viomi-vacuum-v8": ViomiVacuum,
     "zhimi.heater.za1": partial(Heater, model=MODEL_HEATER_ZA1),
     "zhimi.elecheater.ma1": partial(Heater, model=MODEL_HEATER_MA1),
+    "dreame-vacuum-mc1808": DreameVacuum,
+    "dreame-vacuum-p2008": DreameVacuum,
+    "dreame-vacuum-p2028": DreameVacuum,
+    "dreame-vacuum-p2009": DreameVacuum,
 }
 
 
@@ -228,7 +219,7 @@ def get_addr_from_info(info):
 
 def other_package_info(info, desc):
     """Return information about another package supporting the device."""
-    return "Found %s at %s, check %s" % (info.name, get_addr_from_info(info), desc)
+    return f"Found {info.name} at {get_addr_from_info(info)}, check {desc}"
 
 
 def create_device(name: str, addr: str, device_cls: partial) -> Device:
