@@ -114,6 +114,15 @@ class MopMode(enum.Enum):
     Deep = 301
 
 
+class MopIntensity(enum.Enum):
+    """Mop scrub intensity on S7."""
+
+    Close = 200
+    Mild = 201
+    Moderate = 202
+    Intense = 203
+
+
 class CarpetCleaningMode(enum.Enum):
     """Type of carpet cleaning/avoidance."""
 
@@ -128,8 +137,11 @@ ROCKROBO_S4_MAX = "roborock.vacuum.a19"
 ROCKROBO_S5 = "roborock.vacuum.s5"
 ROCKROBO_S5_MAX = "roborock.vacuum.s5e"
 ROCKROBO_S6 = "roborock.vacuum.s6"
+ROCKROBO_T6 = "roborock.vacuum.t6"  # cn s6
 ROCKROBO_S6_PURE = "roborock.vacuum.a08"
+ROCKROBO_T7 = "roborock.vacuum.a11"  # cn s7
 ROCKROBO_T7S = "roborock.vacuum.a14"
+ROCKROBO_T7SPLUS = "roborock.vacuum.a23"
 ROCKROBO_S7 = "roborock.vacuum.a15"
 ROCKROBO_S6_MAXV = "roborock.vacuum.a10"
 ROCKROBO_E2 = "roborock.vacuum.e2"
@@ -142,8 +154,11 @@ SUPPORTED_MODELS = [
     ROCKROBO_S5,
     ROCKROBO_S5_MAX,
     ROCKROBO_S6,
+    ROCKROBO_T6,
     ROCKROBO_S6_PURE,
+    ROCKROBO_T7,
     ROCKROBO_T7S,
+    ROCKROBO_T7SPLUS,
     ROCKROBO_S7,
     ROCKROBO_S6_MAXV,
     ROCKROBO_E2,
@@ -163,7 +178,7 @@ class RoborockVacuum(Device):
         start_id: int = 0,
         debug: int = 0,
         *,
-        model=None
+        model=None,
     ):
         super().__init__(ip, token, start_id, debug, model=model)
         self.manual_seqnum = -1
@@ -214,12 +229,27 @@ class RoborockVacuum(Device):
             return info
         except (TypeError, DeviceInfoUnavailableException):
             # cloud-blocked gen1 vacuums will not return proper payloads
+            def create_dummy_mac(addr):
+                """Returns a dummy mac for a given IP address.
+
+                This squats the FF:FF:<first octet> OUI for a dummy mac presentation to
+                allow presenting a unique identifier for homeassistant.
+                """
+                from ipaddress import ip_address
+
+                ip_to_mac = ":".join(
+                    [f"{hex(x).replace('0x', ''):0>2}" for x in ip_address(addr).packed]
+                )
+                return f"FF:FF:{ip_to_mac}"
+
             dummy_v1 = DeviceInfo(
                 {
                     "model": ROCKROBO_V1,
                     "token": self.token,
                     "netif": {"localIp": self.ip},
-                    "fw_ver": "1.0_dummy",
+                    "mac": create_dummy_mac(self.ip),
+                    "fw_ver": "1.0_nocloud",
+                    "hw_ver": "1st gen non-cloud hw",
                 }
             )
 
@@ -837,6 +867,22 @@ class RoborockVacuum(Device):
         """Set mop mode setting."""
         return self.send("set_mop_mode", [mop_mode.value])[0] == "ok"
 
+    @command()
+    def mop_intensity(self) -> MopIntensity:
+        """Get mop scrub intensity setting."""
+        if self.model != ROCKROBO_S7:
+            raise VacuumException("Mop scrub intensity not supported by %s", self.model)
+
+        return MopIntensity(self.send("get_water_box_custom_mode")[0])
+
+    @command(click.argument("mop_intensity", type=EnumType(MopIntensity)))
+    def set_mop_intensity(self, mop_intensity: MopIntensity):
+        """Set mop scrub intensity setting."""
+        if self.model != ROCKROBO_S7:
+            raise VacuumException("Mop scrub intensity not supported by %s", self.model)
+
+        return self.send("set_water_box_custom_mode", [mop_intensity.value])
+
     @command()
     def child_lock(self) -> bool:
         """Get child lock setting."""
@@ -857,7 +903,7 @@ class RoborockVacuum(Device):
 
             start_id = manual_seq = 0
             with contextlib.suppress(FileNotFoundError, TypeError, ValueError), open(
-                id_file, "r"
+                id_file
             ) as f:
                 x = json.load(f)
                 start_id = x.get("seq", 0)
