@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*#
 from datetime import datetime, time, timedelta, tzinfo
 from enum import IntEnum
 from typing import Any, Dict, List, Optional, Union
@@ -323,7 +322,7 @@ class CleaningDetails(DeviceStatus):
 
         see also :func:`error`.
         """
-        return bool(self.data["complete"] == 1)
+        return self.data["complete"] == 1
 
 
 class ConsumableStatus(DeviceStatus):
@@ -447,7 +446,7 @@ class Timer(DeviceStatus):
     @property
     def enabled(self) -> bool:
         """True if the timer is active."""
-        return bool(self.data[1] == "on")
+        return self.data[1] == "on"
 
     @property
     def cron(self) -> str:
